package net.wanji.databus.entity.develop.servicedevelop.bpm.processengine;

import lombok.Getter;
import lombok.Setter;

import java.util.List;

/**
 * 类描述: 流程设计器保存的流程格式，json原格式示例：
 *{
 * 	"name": "test1",
 * 	"id": "D0AE6D1122F14CF2",
 * 	"nodes": [{
 * 		"id": "wf_node_0",
 * 		"name": "审批节点",
 * 		"code": "approval",
 * 		"type": "flowNode",
 * 		"icon": "workflow/model/plugin/approval/icon.png",
 * 		"x": 306,
 * 		"y": 198.5,
 * 		"status": "",
 * 		"children": {
 * 			"nodes": [],
 * 			"lines": []
 *                }* 	}, {
 * 		"id": "wf_node_1",
 * 		"name": "开始",
 * 		"code": "start",
 * 		"type": "startNode",
 * 		"icon": "workflow/model/plugin/start/icon.png",
 * 		"x": 306,
 * 		"y": 39,
 * 		"status": "",
 * 		"children": {
 * 			"nodes": [],
 * 			"lines": []
 *        }* 	}, {
 * 		"id": "wf_node_2",
 * 		"name": "结束",
 * 		"code": "end",
 * 		"type": "endNode",
 * 		"icon": "workflow/model/plugin/end/icon.png",
 * 		"x": 306,
 * 		"y": 445,
 * 		"status": "",
 * 		"children": {
 * 			"nodes": [],
 * 			"lines": []
 *        }* 	}],
 * 	"lines": [{
 * 		"id": "wf_line_3",
 * 		"type": "sl",
 * 		"from": "wf_node_1",
 * 		"to": "wf_node_0",
 * 		"attr": {}* 	}, {
 * 		"id": "wf_line_4",
 * 		"type": "sl",
 * 		"from": "wf_node_0",
 * 		"to": "wf_node_2",
 * 		"attr": {}* 	}]
 * }
 * @Author
 * @Date 2019/8/8 17:08
 */
@Getter
@Setter
public class ProcessStructureOfJson {

    private String name; //流程名称
    private String id; //流程id
    private List<Node> nodes; //流程节点
    private List<Line> lines; //流程连线

    /*内部类，流程节点，static，否则JsonObject无法自动转换*/
    @Getter
    @Setter
    public static class Node {
        private String id; //节点id
        private String name; //节点名称
        private String type; //节点类型

    }

    /*内部类，流程连线，static，否则JsonObject无法自动转换*/
    @Getter
    @Setter
    public static class Line {
        private String id; //连线id
        private String name; //连线名称，作为条件字段使用
        private String type; //连线类型
        private String from; //开始节点
        private String to; //目标节点

    }
}

