package net.wanji.databus.entity.develop.servicedevelop.bpm.processmanager;

import com.alibaba.fastjson.JSONObject;
import net.wanji.common.framework.domain.TrackableEntity;
import net.wanji.databus.entity.develop.servicedevelop.bpm.processengine.ProcessStructureOfJson;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 类描述: 流程定义数据库实体类
 *
 * @Author
 * @Date 2019/8/26 10:01
 */
@Getter
@Setter
@ApiModel(value = "WorkflowDefinition", description = "流程定义数据库实体类")
public class WorkflowDefinition extends TrackableEntity {

    @ApiModelProperty(value = "id")
    private String id;

    @ApiModelProperty(value = "流程名称", example = "流程1", required = true)
    private String name;

    @ApiModelProperty(value = "流程类型id", example = "1", required = true)
    private String typeId;

    @ApiModelProperty(value = "原始流程g6结构定义")
    private String oriStructure;

    @ApiModelProperty(value = "流程结构化XML")
    private String bpmXml;

    @ApiModelProperty(value = "编码")
    private String code;

    @ApiModelProperty(value = "部署状态，deploy-部署，undeploy-未部署")
    private String deployStatus;

    @ApiModelProperty(value = "版本")
    private String version;

    @ApiModelProperty(value = "部署id")
    private String deploymentId;

    @ApiModelProperty(value = "描述")
    private String remark;

    /*开始节点id*/
    private String startNodeId;
    /*结束节点id*/
    private String endNodeId;

    /**
     * 描述: 构造函数
     *
     * @return net.wanji..design.entity.processdeploy.ProcessId
     * @Author
     * @Date 2019/8/5 17:10
     **/
    public static WorkflowDefinition newInstance() {
        return new WorkflowDefinition();
    }

    /**
     * 描述: 自动更新流程定义开始节点id
     * 表单交互查询中，需要使用流程定义id + 节点id，赋值startNodeId用于开始流程时使用
     *
     * @Author
     * @Date 2019/9/4 10:33
     **/
    public void startNodeIdAutoSet() {
        try {
            ProcessStructureOfJson processStructure = JSONObject.parseObject(this.oriStructure, ProcessStructureOfJson.class);
            List<ProcessStructureOfJson.Node> nodes = processStructure.getNodes()
                    .stream()
                    .filter(node -> "startNode".equals(node.getType()))
                    .collect(Collectors.toList());
            if (!nodes.isEmpty()) {
                this.startNodeId = nodes.get(0).getId();
            }
        } catch (Exception ignored) {
        }
    }

 	/**
     * 描述: 自动更新流程定义结束节点id
     * 流程结束时，无法根据流程获取结束节点id，需要单独解析
     *
     * @Author
     * @Date 2019/9/4 10:33
     **/
    public void endNodeIdAutoSet() {
        try {
            ProcessStructureOfJson processStructure = JSONObject.parseObject(this.oriStructure, ProcessStructureOfJson.class);
            List<ProcessStructureOfJson.Node> nodes = processStructure.getNodes()
                    .stream()
                    .filter(node -> "endNode".equals(node.getType()))
                    .collect(Collectors.toList());
            if (!nodes.isEmpty()) {
                this.endNodeId = nodes.get(0).getId();
            }
        } catch (Exception ignored) {
        }
    }

}
