package net.wanji.databus.entity.identity.identity;

import com.alibaba.fastjson.annotation.JSONField;
import net.wanji.common.framework.domain.TrackableEntity;
import net.wanji.common.framework.rest.ValidationGroups;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import java.util.Date;

/**
 * @Description:
 * @Author wanji
 * @Date 2019/11/27 18:38
 **/
@Getter
@Setter
@ApiModel(value = "BusinessAccount", description = "业务账号")
public class BusinessAccount extends TrackableEntity {

    @ApiModelProperty(value = "机构id")
    @NotBlank(message = "机构id不能为空",groups = {ValidationGroups.Create.class})
    private String organizationId;

    @ApiModelProperty(value = "部门id")
    @NotBlank(message = "部门id不能为空",groups = {ValidationGroups.Create.class})
    private String departmentId;

    @ApiModelProperty(value = "岗位id")
    @NotBlank(message = "岗位id不能为空",groups = { ValidationGroups.Create.class})
    private String stationId;

    @ApiModelProperty(value = "角色id")
    private String roleId;

    @ApiModelProperty(value = "业务账号名称")
    @NotBlank(message = "名称不能为空",groups = {ValidationGroups.Create.class})
    private String name;

    @ApiModelProperty(value = "业务账号登录名")
    @NotBlank(message = "业务账号登录名不能为空",groups = {ValidationGroups.Create.class})
    private String username;

    @ApiModelProperty(value = "盐")
    private String salt;

    @ApiModelProperty(value = "密码")
    @NotBlank(message = "密码不能为空",groups = {ValidationGroups.Create.class})
    private String password;

    @ApiModelProperty(value = "状态：默认为enable，创建即启用;禁用状态disable")
    private String status;

    @ApiModelProperty(value = "邮箱")
    private String email;

    @ApiModelProperty(value = "用户电话")
    private String phone;

    @ApiModelProperty(value = "关联状态relevance,irrelevant")
    private String relevanceStatus;

    @ApiModelProperty(value = "有效期")
    @JSONField(format = "yyyy-MM-dd")
    private Date expiringDate;

    @ApiModelProperty(value = "是否同步到用户中心")
    private Boolean synchronize;
    @ApiModelProperty(value = "是否与用户做账号关联")
    private Boolean relevance;
    // 模糊搜索专用
    private String keyword;

    public String getCredentialsSalt() {
        return username + salt + salt;
    }

    public static BusinessAccount newInstance() {
        return new BusinessAccount();
    }
}
