package net.wanji.databus.entity.identity.identity;

import net.wanji.common.framework.domain.TrackableEntity;
import net.wanji.common.framework.rest.ValidationGroups;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;

/**
 *
 * @author wanji
 * @date 2019/3/5
 */
@Setter
@Getter
@ApiModel(value = "Department",description = "部门")
public class Department extends TrackableEntity {

    @ApiModelProperty(value = "组织机构id")
    @NotBlank(message = "组织机构id不能为空",groups = {ValidationGroups.Create.class})
    private String organizationId;

    @ApiModelProperty(value = "上级部门id")
    private String parentId = "";

    @ApiModelProperty(value = "编码")
    private String code;

    @ApiModelProperty(value = "部门名称")
    @NotBlank(message = "名称不能为空",groups = { ValidationGroups.Create.class})
    private String name;

    @ApiModelProperty(value = "部门全名，只读，根据机构的层次结构自动生成")
    private String fullName = "";

    /**
     * 部门标识
     */
    private String identification = "department";

    // 模糊搜索专用
    private String keyword;

    public static Department newInstance() {
        return new Department();
    }

    /**
     * @Author wanji
     * @Description 重写equals方法
     * @Date 10:30 2020/9/11
     * @Param [obj]
     * @return boolean
     * @throws
     */
    @Override
    public boolean equals(Object obj) {
        Department department = (Department) obj;
        return this.id.equals(department.getId());
    }

    /**
     * @Author wanji
     * @Description 重写hash方法
     * @Date 10:57 2020/9/11
     * @Param []
     * @return int
     * @throws
     */
    @Override
    public int hashCode() {
        return id.hashCode();
    }
}
