package net.wanji.databus.entity.integration.servicegateway.m2a;

import net.wanji.common.framework.rest.JsonViewObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSenderImpl;

import javax.mail.Session;
import java.util.Properties;

/**
 * @ClassName MailUtils
 * @Description 邮件工具类
 * @Author wanji
 * @Date 2020/5/29 13:44
 * @Version 1.0
 */
@Slf4j
public class MailUtils {

    /**
     * @return void
     * @throws
     * @Author wanji
     * @Description 邮件发送
     * @Date 13:57 2020/5/29
     * @Param [m2AMail, map]
     */
    public static JsonViewObject sendSimpleMail(M2AMail m2AMail) {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        // 发送器
        JavaMailSenderImpl sender = new JavaMailSenderImpl();
        try {
            sender.setHost(m2AMail.getServer());
            sender.setPort(Integer.valueOf(m2AMail.getPort()));
            sender.setUsername(m2AMail.getUser());
            sender.setPassword(m2AMail.getPwd());
        } catch (Exception e) {
            log.error("邮件发送器装配异常", e);
            return jsonViewObject.fail("邮件发送器装配异常");
        }
        // 配置文件对象
        try {
            Properties props = new Properties();
            props.put("mail.smtp.auth", m2AMail.isSsl()); // 是否进行验证
            Session session = Session.getInstance(props);
            sender.setSession(session); // 为发送器指定会话
        } catch (Exception e) {
            log.error("文件对象装配异常", e);
            return jsonViewObject.fail("文件对象装配异常");
        }
        SimpleMailMessage mail = new SimpleMailMessage();
        try {
            String[] split = m2AMail.getAddressee().split(";");
            mail.setTo(split);
            //todo 完善抄送，密送
            mail.setSubject(m2AMail.getTitle()); // 标题
            mail.setFrom(m2AMail.getDefaultSender()); // 发件人
            mail.setText(m2AMail.getMessage()); // 邮件内容
        } catch (Exception e) {
            log.error("邮件信息装配异常", e);
            return jsonViewObject.fail("邮件信息装配异常");
        }
        try {
            sender.send(mail); // 发送
            log.info("邮件发送成功");
            jsonViewObject.success("邮件发送成功");
        } catch (Exception e) {
            log.error("邮件发送异常", e);
            jsonViewObject.fail("邮件发送异常");
        }
        return jsonViewObject;
    }
}
